# 🌐 Leonardo da Vinci International Airport

![image](https://github.com/kamangir/assets/blob/main/blue-geo/Leonardo.png?raw=true)

 - [Google Maps](https://maps.app.goo.gl/Zpnj53kVcQQ4fNA17): `lat: 41.8100"N`, `lon: 12.2550"E`.
 - [Wikipedia](https://en.wikipedia.org/wiki/Rome_Fiumicino_Airport): The 9th busiest airport in Europe and the world's 46th-busiest airport with over 40.5 million passengers served in 2023.

---

used by: [`@geo watch`](../).
